@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1996, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1996, 2024, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  *
  *
@@ -48,6 +48,8 @@
 extern "C" {
 #endif
 
+#define JNICALL
+
 /*
  * JNI Types
  */
@@ -775,6 +777,12 @@ struct JNINativeInterface_ {
 
     jboolean (JNICALL *IsVirtualThread)
        (JNIEnv* env, jobject obj);
+
+    /* Large UTF8 Support */
+
+    jlong (JNICALL *GetStringUTFLengthAsLong)
+      (JNIEnv *env, jstring str);
+
 };
 
 /*
@@ -1623,6 +1631,9 @@ struct JNIEnv_ {
     jsize GetStringUTFLength(jstring str) {
         return functions->GetStringUTFLength(this,str);
     }
+    jlong GetStringUTFLengthAsLong(jstring str) {
+        return functions->GetStringUTFLengthAsLong(this,str);
+    }
     const char* GetStringUTFChars(jstring str, jboolean *isCopy) {
         return functions->GetStringUTFChars(this,str,isCopy);
     }
@@ -1993,6 +2004,7 @@ JNI_OnUnload(JavaVM *vm, void *reserved);
 #define JNI_VERSION_19  0x00130000
 #define JNI_VERSION_20  0x00140000
 #define JNI_VERSION_21  0x00150000
+#define JNI_VERSION_24  0x00180000
 
 #ifdef __cplusplus
 } /* extern "C" */
