@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2015, 2024, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  *
  *
@@ -29,15 +29,14 @@ import java.io.IOException;
 import java.io.UncheckedIOException;
 import java.net.InetAddress;
 import java.net.http.HttpResponse.BodyHandlers;
+import java.net.http.HttpResponse.BodySubscriber;
+import java.net.http.HttpResponse.BodySubscribers;
 import java.nio.channels.Selector;
 import java.net.Authenticator;
 import java.net.CookieHandler;
 import java.net.InetSocketAddress;
 import java.net.Proxy;
 import java.net.ProxySelector;
-import java.net.URLPermission;
-import java.security.AccessController;
-import java.security.PrivilegedAction;
 import java.time.Duration;
 import java.util.Objects;
 import java.util.Optional;
@@ -117,48 +116,51 @@ import jdk.internal.net.http.HttpClientBuilderImpl;
  *        .thenApply(HttpResponse::body)
  *        .thenAccept(System.out::println);  }
  *
- * <p> <a id="securitychecks"><b>Security checks</b></a>
- *
- * <p> If a security manager is present then security checks are performed by
- * the HTTP Client's sending methods. An appropriate {@link URLPermission} is
- * required to access the destination server, and proxy server if one has
- * been configured. The form of the {@code URLPermission} required to access a
- * proxy has a {@code method} parameter of {@code "CONNECT"} (for all kinds of
- * proxying) and a {@code URL} string of the form {@code "socket://host:port"}
- * where host and port specify the proxy's address.
- *
  * @apiNote
  * Resources allocated by the {@code HttpClient} may be
  * reclaimed early by {@linkplain #close() closing} the client.
  *
  * @implNote
- *  <p id="closing">
- *  The JDK built-in implementation of the {@code HttpClient} overrides
+ *  <p id="streaming">
+ *  The {@link BodyHandlers} and {@link BodySubscribers}
+ *  classes provide some {@linkplain BodySubscribers##streaming-body streaming
+ *  or publishing {@code BodyHandler} and {@code BodySubscriber}
+ *  implementations} which allow to stream body data back to the caller.
+ *  In order for the resources associated with these streams to be
+ *  reclaimed, and for the HTTP request to be considered completed,
+ *  a caller must eventually {@linkplain  HttpResponse#body()
+ *  obtain the streaming response body} and close, cancel, or
+ *  read the returned streams to exhaustion. Likewise, a custom
+ *  {@link BodySubscriber} implementation should either {@linkplain
+ *  Subscription#request(long) request} all data until {@link
+ *  BodySubscriber#onComplete() onComplete} or {@link
+ *  BodySubscriber#onError(Throwable) onError} is signalled, or eventually
+ *  {@linkplain Subscription#cancel() cancel} its subscription.
+ *
+ * <p id="closing">
+ * The JDK built-in implementation of the {@code HttpClient} overrides
  * {@link #close()}, {@link #shutdown()}, {@link #shutdownNow()},
  * {@link #awaitTermination(Duration)}, and {@link #isTerminated()} to
  * provide a best effort implementation. Failing to close, cancel, or
- * read returned streams to exhaustion, such as streams provided when using
- * {@link BodyHandlers#ofInputStream()}, {@link BodyHandlers#ofLines()}, or
- * {@link BodyHandlers#ofPublisher()}, may prevent requests submitted
- * before an {@linkplain #shutdown() orderly shutdown}
- * to run to completion. Likewise, failing to
- * {@linkplain Subscription#request(long) request data} or {@linkplain
- * Subscription#cancel() cancel subscriptions} from a custom {@linkplain
- * java.net.http.HttpResponse.BodySubscriber BodySubscriber} may stop
- * delivery of data and {@linkplain #awaitTermination(Duration) stall an
- * orderly shutdown}.
+ * read {@link ##streaming streaming or publishing bodies} to exhaustion
+ * may stop delivery of data while leaving the request open, and
+ * {@linkplain #awaitTermination(Duration) stall an
+ * orderly shutdown}. The {@link #shutdownNow()} method, if called, will
+ * attempt to cancel any such non-completed requests, but may cause
+ * abrupt termination of any on going operation.
  *
- * <p>
- * If an explicit {@linkplain HttpClient.Builder#executor(Executor)
- * executor} has not been set for an {@code HttpClient}, and a security manager
- * has been installed, then the default executor will execute asynchronous and
- * dependent tasks in a context that is granted no permissions. Custom
- * {@linkplain HttpRequest.BodyPublisher request body publishers}, {@linkplain
- * HttpResponse.BodyHandler response body handlers}, {@linkplain
- * HttpResponse.BodySubscriber response body subscribers}, and {@linkplain
- * WebSocket.Listener WebSocket Listeners}, if executing operations that require
- * privileges, should do so within an appropriate {@linkplain
- * AccessController#doPrivileged(PrivilegedAction) privileged context}.
+ * <p id="gc">
+ * If not {@linkplain ##closing explicitly closed}, the JDK
+ * built-in implementation of the {@code HttpClient} releases
+ * its resources when an {@code HttpClient} instance is no longer
+ * strongly reachable, and all operations started on that instance have
+ * eventually completed. This relies both on the garbage collector
+ * to notice that the instance is no longer reachable, and on all
+ * requests started on the client to eventually complete. Failure
+ * to properly close {@linkplain ##streaming streaming or publishing bodies}
+ * may prevent the associated requests from running to completion, and
+ * prevent the resources allocated by the associated client from
+ * being reclaimed by the garbage collector.
  *
  * @since 11
  */
@@ -297,9 +299,7 @@ public abstract class HttpClient implements AutoCloseable {
          * HttpClient}.
          *
          * @implNote The default executor uses a thread pool, with a custom
-         * thread factory. If a security manager has been installed, the thread
-         * factory creates threads that run with an access control context that
-         * has no permissions.
+         * thread factory.
          *
          * @param executor the Executor
          * @return this builder
@@ -382,6 +382,14 @@ public abstract class HttpClient implements AutoCloseable {
         /**
          * Sets an authenticator to use for HTTP authentication.
          *
+         * @implNote
+         * In the JDK built-in implementation of the {@code HttpClient},
+         * if a {@link HttpRequest} has an {@code Authorization} or {@code
+         * Proxy-Authorization} header set then its value is used and
+         * the {@link Authenticator} is not invoked for the corresponding
+         * authentication. In this case, any authentication errors are returned
+         * to the user and requests are not automatically retried.
+         *
          * @param authenticator the Authenticator
          * @return this builder
          */
@@ -426,20 +434,12 @@ public abstract class HttpClient implements AutoCloseable {
          * Returns a new {@link HttpClient} built from the current state of this
          * builder.
          *
-         * @implSpec If the {@link #localAddress(InetAddress) local address} is a non-null
-         * address and a security manager is installed, then
-         * this method calls {@link SecurityManager#checkListen checkListen} to check that
-         * the caller has necessary permission to bind to that local address.
-         *
          * @return a new {@code HttpClient}
          *
          * @throws UncheckedIOException may be thrown if underlying IO resources required
          * by the implementation cannot be allocated. For instance,
          * if the implementation requires a {@link Selector}, and opening
          * one fails due to {@linkplain Selector#open() lack of necessary resources}.
-         * @throws SecurityException If a security manager has been installed and the
-         *         security manager's {@link SecurityManager#checkListen checkListen}
-         *         method disallows binding to the given address.
          */
         public HttpClient build();
     }
@@ -635,11 +635,6 @@ public abstract class HttpClient implements AutoCloseable {
      * @throws IllegalArgumentException if the {@code request} argument is not
      *         a request that could have been validly built as specified by {@link
      *         HttpRequest.Builder HttpRequest.Builder}.
-     * @throws SecurityException If a security manager has been installed
-     *          and it denies {@link java.net.URLPermission access} to the
-     *          URL in the given request, or proxy if one is configured.
-     *          See <a href="#securitychecks">security checks</a> for further
-     *          information.
      */
     public abstract <T> HttpResponse<T>
     send(HttpRequest request, HttpResponse.BodyHandler<T> responseBodyHandler)
@@ -679,14 +674,9 @@ public abstract class HttpClient implements AutoCloseable {
      * <ul>
      * <li>{@link IOException} - if an I/O error occurs when sending or receiving,
      *      or the client has {@linkplain ##closing shut down}.</li>
-     * <li>{@link SecurityException} - If a security manager has been installed
-     *          and it denies {@link java.net.URLPermission access} to the
-     *          URL in the given request, or proxy if one is configured.
-     *          See <a href="#securitychecks">security checks</a> for further
-     *          information.</li>
      * </ul>
      *
-     * <p> The default {@code HttpClient} implementation returns
+     * <p id="cancel"> The default {@code HttpClient} implementation returns
      * {@code CompletableFuture} objects that are <em>cancelable</em>.
      * {@code CompletableFuture} objects {@linkplain CompletableFuture#newIncompleteFuture()
      * derived} from cancelable futures are themselves <em>cancelable</em>.
