@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  */
 
@@ -822,6 +822,14 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Kazakhstan = new String[] {
+               "Waktu Kazakhstan",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Seychelles = new String[] {
                "Waktu Seychelles",
                "",
@@ -1166,14 +1174,6 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
                "",
                "WIB",
             };
-        final String[] Kazakhstan_Western = new String[] {
-               "Waktu Kazakhstan Barat",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Australia_CentralWestern = new String[] {
                "Waktu Standar Barat Tengah Australia",
                "",
@@ -1335,7 +1335,7 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
-            { "Asia/Oral", Kazakhstan_Western },
+            { "Asia/Oral", Kazakhstan },
             { "Etc/GMT+0", GMT },
             { "Etc/GMT-0", GMT },
             { "Greenwich", GMT },
@@ -1353,7 +1353,7 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
                     "UTC",
                 }
             },
-            { "Asia/Aqtau", Kazakhstan_Western },
+            { "Asia/Aqtau", Kazakhstan },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
@@ -1369,10 +1369,10 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             { "US/Pacific", America_Pacific },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
-            { "Asia/Almaty", Kazakhstan_Western },
+            { "Asia/Almaty", Kazakhstan },
             { "Asia/Anadyr", Anadyr },
-            { "Asia/Aqtobe", Kazakhstan_Western },
-            { "Asia/Atyrau", Kazakhstan_Western },
+            { "Asia/Aqtobe", Kazakhstan },
+            { "Asia/Atyrau", Kazakhstan },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Brunei", Brunei },
             { "Asia/Harbin", China },
@@ -1472,7 +1472,7 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Qostanay", Kazakhstan_Western },
+            { "Asia/Qostanay", Kazakhstan },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
             { "Asia/Tel_Aviv", Israel },
@@ -1577,7 +1577,7 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
             { "Asia/Pyongyang", Korea },
-            { "Asia/Qyzylorda", Kazakhstan_Western },
+            { "Asia/Qyzylorda", Kazakhstan },
             { "Asia/Samarkand", Uzbekistan },
             { "Asia/Singapore", Singapore },
             { "Asia/Vientiane", Indochina },
